==> kadu_0.6.6~rc1.orig.tar.bz2: kadu-0.6.6-rc1/modules/mediaplayer/translations/mediaplayer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Składnia: %t - tytuł,
%a - album, %r - wykonawca, %f - nazwa pliku,
%l - długość utworu (MM:SS), %c - pozycja odtwarzania (MM:SS),
%p - procent odtwarzania, %n - nazwa odtwarzacza, %v - wersja odtwarzacza
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD dla MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>MediaPlayer message format for chat windows</source>
        <translation>Format wiadomości dla okien rozmowy</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Status opisowy</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zamień</translation>
    </message>
    <message>
        <source>Add in front</source>
        <translation>Dodaj na początku</translation>
    </message>
    <message>
        <source>Add at the back</source>
        <translation>Dodaj na końcu</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; tag</source>
        <translation>Zastąp frazę &apos;#{player}&apos;</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Format opisu</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Podaj format, który zastąpi frazę &apos;#{player}&apos; użytą w statusie opisowym.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Sygnatury</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Sygnatury, które zostaną usunięte</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Włącz pseudo-OSD</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Włącza pseudo-OSD realizowane przez mechanizm powiadomien Kadu. Na przykład pokazuje aktualnie grany utwór w dymku.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Włącz skróty klawiaturowe MediaPlayer w oknie rozmowy</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Wstaw włącznik statusów w menu dokowania</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Dodaj przełącznik statusów MediaPlayer do menu dokowania.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Ogólne ustawienia</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Usuwanie sygnatur</translation>
    </message>
    <message>
        <source>Shall I cut this crap?</source>
        <translation>Czy mam obciąc ten fragment?</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Inne ustawienia</translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Po włączeniu tej opcji będziesz móc kontrolować
swój odtwarzacz z okna rozmowy za pomocą następujących skrótów:
Control+ Enter/Backspace/Left/Right/Up/Down.Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Wstaw sformatowany łańcuch</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Wstaw nazwę odtwarzanego pliku</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Wstaw tytuł utworu</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Wyślij wszystkie tytuły z listy odtwarzania</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Wyślij wszystki nazwy plików z listy odtwarzania</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Włącz statusy MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 nie jest uruchomiony!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Próbujesz wysłać %1 wpisów z listy odtwarzania %2.&lt;br&gt;Wpisy zostaną podzielone na kilka wiadomości.&lt;br&gt;Na pewno wysłac?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Odtwarzanie zatrzymane.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Odtwarzacz wyłączony.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Włącz statusy Media Playera</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Następny</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Zgłośnij</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Ścisz</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Więcej niż 1/10 tytułów, które próbujesz wysłać, jest pusta.&lt;br&gt;Być może %1 nie odczytał jeszcze wszystkich tytułów. Zaleca się odczekanie chwili. &lt;br&gt;Wysłać listę mimo to?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
</context>
</TS>

==> kadu_0.9.1.orig.tar.bz2: kadu-0.9.1/modules/mediaplayer/translations/mediaplayer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Składnia: %t - tytuł,
%a - album, %r - wykonawca, %f - nazwa pliku,
%l - długość utworu (MM:SS), %c - pozycja odtwarzania (MM:SS),
%p - procent odtwarzania, %n - nazwa odtwarzacza, %v - wersja odtwarzacza
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD dla MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>MediaPlayer message format for chat windows</source>
        <translation>Format wiadomości dla okien rozmowy</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Status opisowy</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zamień</translation>
    </message>
    <message>
        <source>Add in front</source>
        <translation>Dodaj na początku</translation>
    </message>
    <message>
        <source>Add at the back</source>
        <translation>Dodaj na końcu</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; tag</source>
        <translation>Zastąp frazę &apos;#{player}&apos;</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Format opisu</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Podaj format, który zastąpi frazę &apos;#{player}&apos; użytą w statusie opisowym.</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>Sygnatury</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Sygnatury, które zostaną usunięte</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>Włącz pseudo-OSD</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Włącza pseudo-OSD realizowane przez mechanizm powiadomien Kadu. Na przykład pokazuje aktualnie grany utwór w dymku.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Włącz skróty klawiaturowe MediaPlayer w oknie rozmowy</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Wstaw włącznik statusów w menu dokowania</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Dodaj przełącznik statusów MediaPlayer do menu dokowania.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Ogólne ustawienia</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>Usuwanie sygnatur</translation>
    </message>
    <message>
        <source>Shall I cut this crap?</source>
        <translation>Czy mam obciąc ten fragment?</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Inne ustawienia</translation>
    </message>
	<message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Control+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Po włączeniu tej opcji będziesz móc kontrolować
swój odtwarzacz z okna rozmowy za pomocą następujących skrótów:
Control+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>With this option enabled you&apos;ll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Po włączeniu tej opcji będziesz móc kontrolować
swój odtwarzacz z okna rozmowy za pomocą następujących skrótów:
Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Wstaw sformatowany łańcuch</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Wstaw nazwę odtwarzanego pliku</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Wstaw tytuł utworu</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Wyślij wszystkie tytuły z listy odtwarzania</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Wyślij wszystki nazwy plików z listy odtwarzania</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Włącz statusy MediaPlayer</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 nie jest uruchomiony!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>Próbujesz wysłać %1 wpisów z listy odtwarzania %2.&lt;br&gt;Wpisy zostaną podzielone na kilka wiadomości.&lt;br&gt;Na pewno wysłac?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Odtwarzanie zatrzymane.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Odtwarzacz wyłączony.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Włącz statusy Media Playera</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Odtwarzaj</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Następny</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Zgłośnij</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Ścisz</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>Więcej niż 1/10 tytułów, które próbujesz wysłać, jest pusta.&lt;br&gt;Być może %1 nie odczytał jeszcze wszystkich tytułów. Zaleca się odczekanie chwili. &lt;br&gt;Wysłać listę mimo to?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
</context>
</TS>
